@@ -14,9 +14,7 @@ pub(crate) mod atomic_dur;
 #[cfg(not(unix))]
 pub(crate) mod delay_drop;
 #[macro_use]
-pub mod mpmc;
-#[macro_use]
-pub mod mpsc;
+pub mod channel;
 
 pub use self::atomic_option::AtomicOption;
 pub use self::blocking::{Blocker, FastBlocker};
@@ -28,3 +26,4 @@ pub use self::sync_flag::SyncFlag;
 pub use self::wait_group::*;
 pub use self::sync_map::*;
 pub use self::once::*;
+pub use self::channel::*;
