@@ -2,17 +2,19 @@ use std::alloc::Layout;
 use std::fmt::{Debug, Display, Formatter};
 use std::ops::{Add, Deref, DerefMut, Sub};
 use std::time::SystemTime;
-use once_cell::sync::Lazy;
 use serde::de::Error;
 use time::{format_description, OffsetDateTime, UtcOffset};
 use time::error::InvalidFormatDescription;
 use time::format_description::FormatItem;
 use crate::std::time::format::{longDayNames, longMonthNames};
 use crate::std::errors::Result;
+use crate::std::lazy::sync::Lazy;
 use crate::std::time::sys::Timespec;
 
 /// "Mon, 02 Jan 2006 15:04:05 GMT"
 pub const TimeFormat: &'static str = "[weekday repr:short], [day] [month repr:short] [year] [hour]:[minute]:[second] GMT";
+/// "2006-01-02T15:04:05"
+pub const RFC3339Second: &'static str = "[year]-[month]-[day]T[hour]:[minute]:[second]";
 /// "2006-01-02T15:04:05Z07:00"
 pub const RFC3339: &'static str = "[year]-[month]-[day]T[hour]:[minute]:[second][offset_hour sign:mandatory]:[offset_minute]";
 ///"2006-01-02T15:04:05.999999999Z07:00"
@@ -20,6 +22,7 @@ pub const RFC3339Nano: &'static str = "[year]-[month]-[day]T[hour]:[minute]:[sec
 ///"Mon, 02 Jan 2006 15:04:05 MST"
 pub const RFC1123: &'static str = "[weekday repr:short], [day] [month repr:short] [year] [hour]:[minute]:[second] MST";
 
+
 /// Obtain the offset of Utc time and Local time in seconds, using Lazy only once to improve performance
 pub static GLOBAL_OFFSET: Lazy<UtcOffset> = Lazy::new(|| {
     UtcOffset::from_whole_seconds(Timespec::now().local().tm_utcoff).unwrap()
@@ -210,7 +213,7 @@ impl Time {
     }
 
     pub fn now_utc() -> Time {
-        let mut now = time::OffsetDateTime::now_utc();
+        let now = time::OffsetDateTime::now_utc();
         return Time {
             inner: now
         };
@@ -376,8 +379,8 @@ impl Month {
     pub fn i64(&self) -> i64 {
         self.into()
     }
-    // String returns the English name of the month ("January", "February", ...).
-    pub fn String(&self) -> String {
+    // string returns the English name of the month ("January", "February", ...).
+    pub fn string(&self) -> String {
         if Month::January <= *self && *self <= Month::December {
             return longMonthNames[(self.i64() - 1) as usize].to_string();
         }
@@ -385,14 +388,14 @@ impl Month {
         for _ in 0..20 {
             buf.push(0);
         }
-        let n = fmtInt(&mut buf, self.i64() as u64) as usize;
+        let n = fmt_int(&mut buf, self.i64() as u64) as usize;
         return "%!month(".to_string() + &String::from_utf8(buf[n..].to_vec()).unwrap_or_default() + ")";
     }
 }
 
-// fmtInt formats v into the tail of buf.
+// fmt_int formats v into the tail of buf.
 // It returns the index where the output begins.
-fn fmtInt(buf: &mut Vec<u8>, mut v: u64) -> i64 {
+fn fmt_int(buf: &mut Vec<u8>, mut v: u64) -> i64 {
     let mut w = buf.len();
     if v == 0 {
         w -= 1;
@@ -445,7 +448,7 @@ impl Weekday {
             Weekday::Saturday => { 6 }
         }
     }
-    pub fn String(&self) -> String {
+    pub fn string(&self) -> String {
         if Weekday::Sunday <= *self && *self <= Weekday::Saturday {
             return longDayNames[self.i64() as usize].to_string();
         }
@@ -453,7 +456,7 @@ impl Weekday {
         for _ in 0..20 {
             buf.push(0u8);
         }
-        let n = fmtInt(&mut buf, self.i64() as u64);
+        let n = fmt_int(&mut buf, self.i64() as u64);
         return format!("%!weekday({})", String::from_utf8(buf[n as usize..].to_vec()).unwrap_or_default());
     }
 }
@@ -468,8 +471,8 @@ mod test {
     #[test]
     fn test_mon() {
         let m = Month::May;
-        println!("{}", m.String());
-        assert_eq!("May", m.String());
+        println!("{}", m.string());
+        assert_eq!("May", m.string());
     }
 
 
